==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/viking2/dialogs_es.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")
dialogStr("Esta nave se debe de haber hundido desde hace mucho tiempo.")


dialogId("dr1-v-urcite", "font_big", "Definitely. It`s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")
dialogStr("Definitivamente. Es una de las drakkars más antiguas. Juzgando por la forma de la proa, el número de espirales y el color del agua pienso que perteneció al abuelo de Eric el Rojo.")


dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")
dialogStr("O al suegro de Olafo el Bravo.")


dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")
dialogStr("O quizás al tío abuelo de Leif el Hábil.")


dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")
dialogStr("También podría pertenecer a la sobrina de Harold el Grande.")


dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")
dialogStr("O posiblemente a la tía de Snorr el Intrépido.")


dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")
dialogStr("Es incluso posible que perteneciera a Thorson el Duro.")


dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it`s never too late to start a new life!")
dialogStr("Yo siempre pensé que era el barco pesquero de Eric el Incapaz... Pero hoy supe la verdad. ¡Si, nunca es demasiado tarde para comenzar una nueva vida!")


dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")
dialogStr("Mira ese pobre perro.")


dialogId("dr-m-nedycha", "font_small", "Doesn't he seem to be breathing kind of strangely?")
dialogStr("¿No parece estar respirando en forma extraña?")


dialogId("dr-v-napsa", "font_big", "For a dog under water I think he's doing rather well.")
dialogStr("Siendo un perro bajo el agua creo que lo está haciendo bien.")


dialogId("dr-v-nato", "font_big", "He doesn't look all that bad considering that he's been here for a few centuries.")
dialogStr("El no se ve tan mal considerando que ha estado aquí por unas pocas centurias.")


dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")
dialogStr("¡Silencio!")


dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")
dialogStr("¡Te vas a callar!")


dialogId("dr-8-nenechas", "font_viking8", "So, you`re not going to shut up, are you?")
dialogStr("Entonces, ¿No te vas a callar, o si?")


dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")
dialogStr("Aaaaahhh...")


dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")
dialogStr("He-he-he-he-he... Eh-eh-eh-eh...")


dialogId("dr-5-srab1", "font_viking5", "Is it over?")
dialogStr("¿Terminó?")


dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")
dialogStr("¿Estamos a salvo ahora?")


dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")
dialogStr("¿Terminó la pelea?")


dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")
dialogStr("¿Se fué el enemigo al final?")


dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")
dialogStr("¿Todavía estamos peleando?")


dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")
dialogStr("¿Todavía estamos en el Valhalla, jefe?")


dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")
dialogStr("¿Cuando vamos a llegar al Valhalla?")


dialogId("dr-1-aztambudem", "font_viking1", "I`ll let you know once we get there.")
dialogStr("Te lo haré saber cuando lleguemos allí.")


dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")
dialogStr("¿Me puede relevar, señor?")


dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")
dialogStr("Espera a que lleguemos al Valhalla.")


dialogId("dr-2-netrva", "font_viking2", "Isn`t this journey to Valhalla taking a bit too long?")
dialogStr("¿No nos está tomando mucho esta jornada al Valhalla?")


dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")
dialogStr("Paciencia es la señal de un guerrero verdadero.")


dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")
dialogStr("¿Estás seguro que de esta forma se llega al Valhalla?")


dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")
dialogStr("¡Un guerrero debe de confiar en su comandante!")


dialogId("dr-1-achjo", "font_viking1", "Ahhh, I`m in charge of a ship full of cowards.")
dialogStr("Ahhh, estoy a cargo de una nave llena de cobardes.")


dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")
dialogStr("¿Porqué tuve que conseguir una nave llena de bufones?")


dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I`ll go drown myself.")
dialogStr("Bufones, un perro baboso, creo que me voy a ahogar yo mismo.")


dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")
dialogStr("Los Vikingos de verdad tienen barbas.")


dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")
dialogStr("B-b-barbas están de moda ho-hoy en d-d-día.")


dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")
dialogStr("¿Qué clase de capricho es ese, trenzas? Por favor...")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("D-d-das Wikinger M-m-modemagazin empfiehlt ei-einen blonden Zopf a-als Ergänzung zu einem d-dunklem Helm und einem bb-blauen Schild.")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("M-m-moda Vikinga M-m-mensual r-recomienda una barba rubia para complementar un c-casco os-os-oscuro y una coraza a-a-azul.")


dialogId("dr-3-stakovou", "font_viking3", "I simply don`t agree with such a fad.")
dialogStr("Simplemente no estoy de acuerdo con ese capricho.")


dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")
dialogStr("En lugar de eso deberías apegarte a las tradiciones Vikingas.")


dialogId("dr-4-moderni", "font_viking4", "B-b-but I`m c-c-cool!")
dialogStr("¡P-p-pero soy lo m-m-máximo!")


dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")
dialogStr("¡Incluso Erik El G-g-grande llevaba t-t-trenzas!")


dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")
dialogStr("Ridículo. El tenía barba.")


dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")
dialogStr("Pero e-él también u-u-usaba t-trenzas.")


dialogId("dr-3-nemel", "font_viking3", "He did not. And that`s final.")
dialogStr("El no usaba. Y punto final.")


dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")
dialogStr("¿T-t-tu crees que una b-b-barba me quedaría m-m-mejor?")


dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")
dialogStr("Definitivamente.")


dialogId("dr-4-budu", "font_viking4", "I`ll th-th-think it o-over.")
dialogStr("Lo v-v-voy a p-p-pensar.")


dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")
dialogStr("Hmmm... Ehmmm... Hahmmm...")


dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")
dialogStr("N-no, t-t-trenzas son d-definitivamente m-m-mejor.")


dialogId("dr-3-mladez", "font_viking3", "Today`s youth - absolutely unbelievable.")
dialogStr("La juventud de hoy - absolutamente increíble.")


dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It`s unheard of.")
dialogStr("Un guerrero con trenzas. No había escuchado eso.")


dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")
dialogStr("Ustedes jóvenes nada más piensan que pueden salirse con la suya en todo hoy en día.")


dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")
dialogStr("Bueno, yo todavía me veo bien.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking2/dialogs_es.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")
dialogStr("Esta nave se debe de haber hundido desde hace mucho tiempo.")


dialogId("dr1-v-urcite", "font_big", "Definitely. It’s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")
dialogStr("Definitivamente. Es una de las drakkars más antiguas. Juzgando por la forma de la proa, el número de espirales y el color del agua pienso que perteneció al abuelo de Eric el Rojo.")


dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")
dialogStr("O al suegro de Olafo el Bravo.")


dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")
dialogStr("O quizás al tío abuelo de Leif el Hábil.")


dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")
dialogStr("También podría pertenecer a la sobrina de Harold el Grande.")


dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")
dialogStr("O posiblemente a la tía de Snorr el Intrépido.")


dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")
dialogStr("Es incluso posible que perteneciera a Thorson el Duro.")


dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it’s never too late to start a new life!")
dialogStr("Yo siempre pensé que era el barco pesquero de Eric el Incapaz... Pero hoy supe la verdad. ¡Si, nunca es demasiado tarde para comenzar una nueva vida!")


dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")
dialogStr("Mira ese pobre perro.")


dialogId("dr-m-nedycha", "font_small", "Doesn't he seem to be breathing kind of strangely?")
dialogStr("¿No parece estar respirando en forma extraña?")


dialogId("dr-v-napsa", "font_big", "For a dog under water I think he's doing rather well.")
dialogStr("Siendo un perro bajo el agua creo que lo está haciendo bien.")


dialogId("dr-v-nato", "font_big", "He doesn't look all that bad considering that he's been here for a few centuries.")
dialogStr("El no se ve tan mal considerando que ha estado aquí por unas pocas centurias.")


dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")
dialogStr("¡Silencio!")


dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")
dialogStr("¡Te vas a callar!")


dialogId("dr-8-nenechas", "font_viking8", "So, you’re not going to shut up, are you?")
dialogStr("Entonces, ¿No te vas a callar, o si?")


dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")
dialogStr("Aaaaahhh...")


dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")
dialogStr("He-he-he-he-he... Eh-eh-eh-eh...")


dialogId("dr-5-srab1", "font_viking5", "Is it over?")
dialogStr("¿Terminó?")


dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")
dialogStr("¿Estamos a salvo ahora?")


dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")
dialogStr("¿Terminó la pelea?")


dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")
dialogStr("¿Se fué el enemigo al final?")


dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")
dialogStr("¿Todavía estamos peleando?")


dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")
dialogStr("¿Todavía estamos en el Valhalla, jefe?")


dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")
dialogStr("¿Cuando vamos a llegar al Valhalla?")


dialogId("dr-1-aztambudem", "font_viking1", "I’ll let you know once we get there.")
dialogStr("Te lo haré saber cuando lleguemos allí.")


dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")
dialogStr("¿Me puede relevar, señor?")


dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")
dialogStr("Espera a que lleguemos al Valhalla.")


dialogId("dr-2-netrva", "font_viking2", "Isn’t this journey to Valhalla taking a bit too long?")
dialogStr("¿No nos está tomando mucho esta jornada al Valhalla?")


dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")
dialogStr("Paciencia es la señal de un guerrero verdadero.")


dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")
dialogStr("¿Estás seguro que de esta forma se llega al Valhalla?")


dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")
dialogStr("¡Un guerrero debe de confiar en su comandante!")


dialogId("dr-1-achjo", "font_viking1", "Ahhh, I’m in charge of a ship full of cowards.")
dialogStr("Ahhh, estoy a cargo de una nave llena de cobardes.")


dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")
dialogStr("¿Porqué tuve que conseguir una nave llena de bufones?")


dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I’ll go drown myself.")
dialogStr("Bufones, un perro baboso, creo que me voy a ahogar yo mismo.")


dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")
dialogStr("Los Vikingos de verdad tienen barbas.")


dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")
dialogStr("B-b-barbas están de moda ho-hoy en d-d-día.")


dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")
dialogStr("¿Qué clase de capricho es ese, trenzas? Por favor...")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("D-d-das Wikinger M-m-modemagazin empfiehlt ei-einen blonden Zopf a-als Ergänzung zu einem d-dunklem Helm und einem bb-blauen Schild.")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("M-m-moda Vikinga M-m-mensual r-recomienda una barba rubia para complementar un c-casco os-os-oscuro y una coraza a-a-azul.")


dialogId("dr-3-stakovou", "font_viking3", "I simply don’t agree with such a fad.")
dialogStr("Simplemente no estoy de acuerdo con ese capricho.")


dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")
dialogStr("En lugar de eso deberías apegarte a las tradiciones Vikingas.")


dialogId("dr-4-moderni", "font_viking4", "B-b-but I’m c-c-cool!")
dialogStr("¡P-p-pero soy lo m-m-máximo!")


dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")
dialogStr("¡Incluso Erik El G-g-grande llevaba t-t-trenzas!")


dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")
dialogStr("Ridículo. El tenía barba.")


dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")
dialogStr("Pero e-él también u-u-usaba t-trenzas.")


dialogId("dr-3-nemel", "font_viking3", "He did not. And that’s final.")
dialogStr("El no usaba. Y punto final.")


dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")
dialogStr("¿T-t-tu crees que una b-b-barba me quedaría m-m-mejor?")


dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")
dialogStr("Definitivamente.")


dialogId("dr-4-budu", "font_viking4", "I’ll th-th-think it o-over.")
dialogStr("Lo v-v-voy a p-p-pensar.")


dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")
dialogStr("Hmmm... Ehmmm... Hahmmm...")


dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")
dialogStr("N-no, t-t-trenzas son d-definitivamente m-m-mejor.")


dialogId("dr-3-mladez", "font_viking3", "Today’s youth - absolutely unbelievable.")
dialogStr("La juventud de hoy - absolutamente increíble.")


dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It’s unheard of.")
dialogStr("Un guerrero con trenzas. No había escuchado eso.")


dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")
dialogStr("Ustedes jóvenes nada más piensan que pueden salirse con la suya en todo hoy en día.")


dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")
dialogStr("Bueno, yo todavía me veo bien.")
